==> zio-aws-rds_3-5.17.128.1-sources.jar: zio/aws/rds/model/ModifyDbProxyEndpointResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ModifyDbProxyEndpointResponse(
    dbProxyEndpoint: scala.Option[zio.aws.rds.model.DBProxyEndpoint] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ModifyDbProxyEndpointResponse = {
    import ModifyDbProxyEndpointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ModifyDbProxyEndpointResponse
      .builder()
      .optionallyWith(dbProxyEndpoint.map(value => value.buildAwsValue()))(
        _.dbProxyEndpoint
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.ModifyDbProxyEndpointResponse.ReadOnly =
    zio.aws.rds.model.ModifyDbProxyEndpointResponse.wrap(buildAwsValue())
}
object ModifyDbProxyEndpointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ModifyDbProxyEndpointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ModifyDbProxyEndpointResponse =
      zio.aws.rds.model.ModifyDbProxyEndpointResponse(
        dbProxyEndpoint.map(value => value.asEditable)
      )
    def dbProxyEndpoint
        : scala.Option[zio.aws.rds.model.DBProxyEndpoint.ReadOnly]
    def getDbProxyEndpoint
        : ZIO[Any, AwsError, zio.aws.rds.model.DBProxyEndpoint.ReadOnly] =
      AwsError.unwrapOptionField("dbProxyEndpoint", dbProxyEndpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbProxyEndpointResponse
  ) extends zio.aws.rds.model.ModifyDbProxyEndpointResponse.ReadOnly {
    override val dbProxyEndpoint
        : scala.Option[zio.aws.rds.model.DBProxyEndpoint.ReadOnly] = scala
      .Option(impl.dbProxyEndpoint())
      .map(value => zio.aws.rds.model.DBProxyEndpoint.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbProxyEndpointResponse
  ): zio.aws.rds.model.ModifyDbProxyEndpointResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-rds_3-5.17.169.1-sources.jar: zio/aws/rds/model/ModifyDbProxyEndpointResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ModifyDbProxyEndpointResponse(
    dbProxyEndpoint: Optional[zio.aws.rds.model.DBProxyEndpoint] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ModifyDbProxyEndpointResponse = {
    import ModifyDbProxyEndpointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ModifyDbProxyEndpointResponse
      .builder()
      .optionallyWith(dbProxyEndpoint.map(value => value.buildAwsValue()))(
        _.dbProxyEndpoint
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.ModifyDbProxyEndpointResponse.ReadOnly =
    zio.aws.rds.model.ModifyDbProxyEndpointResponse.wrap(buildAwsValue())
}
object ModifyDbProxyEndpointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ModifyDbProxyEndpointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ModifyDbProxyEndpointResponse =
      zio.aws.rds.model.ModifyDbProxyEndpointResponse(
        dbProxyEndpoint.map(value => value.asEditable)
      )
    def dbProxyEndpoint: Optional[zio.aws.rds.model.DBProxyEndpoint.ReadOnly]
    def getDbProxyEndpoint
        : ZIO[Any, AwsError, zio.aws.rds.model.DBProxyEndpoint.ReadOnly] =
      AwsError.unwrapOptionField("dbProxyEndpoint", dbProxyEndpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbProxyEndpointResponse
  ) extends zio.aws.rds.model.ModifyDbProxyEndpointResponse.ReadOnly {
    override val dbProxyEndpoint
        : Optional[zio.aws.rds.model.DBProxyEndpoint.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbProxyEndpoint())
        .map(value => zio.aws.rds.model.DBProxyEndpoint.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbProxyEndpointResponse
  ): zio.aws.rds.model.ModifyDbProxyEndpointResponse.ReadOnly = new Wrapper(
    impl
  )
}
